@@ -68,6 +68,7 @@
 ;; The following functions setup interaction between the main
 ;; PuppetDB components.
 
+(def version (pl-utils/get-version-from-manifest))
 (def configuration nil)
 (def mq-addr "vm://localhost?jms.prefetchPolicy.all=1&create=false")
 (def mq-endpoint "com.puppetlabs.puppetdb.commands")
@@ -97,11 +98,11 @@
    (fn [exception]
      (log/error exception "Error during DB compaction"))
 
-   (Thread/sleep (* 60 1000 interval))
    (log/info "Beginning database compaction")
    (with-transacted-connection db
      (scf-store/garbage-collect!)
-     (log/info "Finished database compaction"))))
+     (log/info "Finished database compaction"))
+   (Thread/sleep (* 60 1000 interval))))
 
 (defn configure-commandproc-threads
   "Update the supplied config map with the number of
@@ -202,6 +203,9 @@
                                                                  :endpoint          mq-endpoint}}
         ring-app                                   (server/build-app globals)]
 
+    (when version
+      (log/info (format "PuppetDB version %s" version)))
+
     ;; Ensure the database is migrated to the latest version
     (sql/with-connection db
       (migrate!))
